@@ -2,10 +2,10 @@ withr::with_output_sink("test-targeteval.Rout", {
 
 test_that("target.evaluator", {
 
-target.runner <- function(experiment, scenario)
+target_runner <- function(experiment, scenario)
   list(call = toString(experiment))
 
-target.evaluator <- function(experiment, num_configurations, all_conf_id,
+target_evaluator <- function(experiment, num_configurations, all_conf_id,
                              scenario, target_runner_call)
   list(cost = runif(1), call = toString(experiment))
 
@@ -13,9 +13,9 @@ parameters <- readParameters(text = '
 algorithm       "--"                 c          (as,mmas,eas,ras,acs)
 ')
 
-   generate.set.seed()
+   generate_set_seed()
    scenario <- checkScenario(list(
-     targetRunner = target.runner, targetEvaluator = target.evaluator,
+     targetRunner = target_runner, targetEvaluator = target_evaluator,
      maxExperiments = 200, instances = runif(100),
      parameters = parameters))
    irace:::checkTargetFiles(scenario = scenario)
